package ir.myket.developerapi;

import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.text.Html;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;

import ir.myket.developerapi.util.MyketResult;
import ir.myket.developerapi.util.MyketSupportHelper;
import ir.myket.developerapi.util.Update;

public class MainActivity extends AppCompatActivity {
	private static final String TAG = "MainActivity";
	private ProgressDialog loadingDialog;
	private MyketSupportHelper mMyketHelper;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		connectService();
	}

	private void connectService() {
		Log.d(TAG, "Creating helper.");
		mMyketHelper = new MyketSupportHelper(this);
		// Enable debug logging (for a production application, you should set this to false).
		mMyketHelper.enableDebugLogging(true);

		// Start setup. This is asynchronous and the specified listener will be called once setup completes.
		Log.d(TAG, "Starting setup.");

		showLoading(true);
		mMyketHelper.startSetup(new MyketSupportHelper.OnMyketSetupFinishedListener() {
			@Override
			public void onMyketSetupFinished(MyketResult result) {
				Log.d(TAG, "Setup finished.");

				if (!result.isSuccess()) {
					// Oh noes, there was a problem or isDeveloperApiSupport is equal false.
					// We suggest the app becomes closed if Myket is not installed or its too old.
					showLoading(false);
					alert(getString(R.string.problem_error_api_connect));
					return;
				}

				mMyketHelper.getAppUpdateStateAsync(mCheckAppUpdateListener);
			}
		});
	}

	private MyketSupportHelper.CheckAppUpdateListener mCheckAppUpdateListener = new MyketSupportHelper
			.CheckAppUpdateListener() {
		@Override
		public void onCheckAppUpdateFinished(MyketResult result, Update update) {
			showLoading(false);
			if (!result.isSuccess()) {
				alert(getString(R.string.problem_in_myket_service));
				return;
			}

			if (update.isUpdateAvailable()) {
				updateAlert(update.getDescription());
			} else {
				alert(getString(R.string.you_already_have_the_lastest_version));
			}
		}
	};

	private void showLoading(boolean show) {
		if (show) {
			loadingDialog = ProgressDialog.show(this, "", getString(R.string.wait_for_server_response),
					true);
		} else {
			if (loadingDialog != null)
				loadingDialog.dismiss();
		}
	}

	private void updateAlert(String message) {
//		getString(R.string.new_version_is_available)
//		getString(R.string.update), getString(R.string.close)
		AlertDialog.Builder bld = new AlertDialog.Builder(this);

		final AlertDialog ad = bld.create();

		// Use LinearLayout to have the same dialog in all android versions
		LinearLayout layout = (LinearLayout) LayoutInflater.from(this).inflate(R.layout.alert_layout, null);
		TextView body = (TextView) layout.findViewById(R.id.tvBody);
		Button detail = (Button) layout.findViewById(R.id.btnAppDetail);
		Button download = (Button) layout.findViewById(R.id.btnAppDownload);
		detail.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View view) {
				openMyketAppDetail();
			}
		});
		download.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View view) {
				openMyketAppDetailAndDownload();
			}
		});
		body.setText(Html.fromHtml(message));
		ad.setView(layout);
		ad.show();
	}

	private void alert(String message) {
		AlertDialog.Builder bld = new AlertDialog.Builder(this);

		final AlertDialog ad = bld.create();
		LinearLayout layout = (LinearLayout) LayoutInflater.from(this).inflate(R.layout.alert_layout, null);
		TextView body = (TextView) layout.findViewById(R.id.tvBody);
		Button detail = (Button) layout.findViewById(R.id.btnAppDetail);
		Button download = (Button) layout.findViewById(R.id.btnAppDownload);
		download.setVisibility(View.INVISIBLE);
		body.setText(message);
		detail.setText(getString(R.string.commit));
		detail.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View view) {
				ad.dismiss();
				finish();
			}
		});
		ad.setView(layout);
		ad.show();
	}

	private void openMyketAppDetail() {
		openIntent("myket://details?id=" + getPackageName());
	}

	private void openMyketAppDetailAndDownload() {
		openIntent("myket://download/" + getPackageName());
	}

	private void openIntent(String url) {
		Intent intent = new Intent();
		intent.setAction(Intent.ACTION_VIEW);
		intent.setFlags(Intent.FLAG_ACTIVITY_NO_HISTORY);
		intent.setData(Uri.parse(url));
		startActivity(intent);
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		// important:
		Log.d(TAG, "Destroying helper.");
		if (mMyketHelper != null)
			mMyketHelper.dispose();
		mMyketHelper = null;
	}
}
